api.cases.v2.test_helpers.case package — Argus-Toolbelt 1.0 documentation

# api.cases.v2.test_helpers.case package

## Submodules

## api.cases.v2.test_helpers.case.acknowledge_workflow module

`api.cases.v2.test_helpers.case.acknowledge_workflow.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/acknowledge, respond with HTTP 403

`api.cases.v2.test_helpers.case.acknowledge_workflow.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/acknowledge, respond with HTTP 404

`api.cases.v2.test_helpers.case.acknowledge_workflow.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/acknowledge, respond with HTTP 200

`api.cases.v2.test_helpers.case.acknowledge_workflow.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/acknowledge, respond with HTTP 401

## api.cases.v2.test_helpers.case.add_attachment module

`api.cases.v2.test_helpers.case.add_attachment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 403

`api.cases.v2.test_helpers.case.add_attachment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 404

`api.cases.v2.test_helpers.case.add_attachment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 200

`api.cases.v2.test_helpers.case.add_attachment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 401

## api.cases.v2.test_helpers.case.add_case_link module

`api.cases.v2.test_helpers.case.add_case_link.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.add_case_link.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.add_case_link.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.add_case_link.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.add_case_tag module

`api.cases.v2.test_helpers.case.add_case_tag.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 403

`api.cases.v2.test_helpers.case.add_case_tag.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 404

`api.cases.v2.test_helpers.case.add_case_tag.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 200

`api.cases.v2.test_helpers.case.add_case_tag.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 401

## api.cases.v2.test_helpers.case.add_case_watcher module

`api.cases.v2.test_helpers.case.add_case_watcher.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 403

`api.cases.v2.test_helpers.case.add_case_watcher.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 404

`api.cases.v2.test_helpers.case.add_case_watcher.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 200

`api.cases.v2.test_helpers.case.add_case_watcher.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 401

## api.cases.v2.test_helpers.case.add_comment module

`api.cases.v2.test_helpers.case.add_comment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 403

`api.cases.v2.test_helpers.case.add_comment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 404

`api.cases.v2.test_helpers.case.add_comment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 200

`api.cases.v2.test_helpers.case.add_comment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 401

## api.cases.v2.test_helpers.case.advanced_case_search module

`api.cases.v2.test_helpers.case.advanced_case_search.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/search, respond with HTTP 403

`api.cases.v2.test_helpers.case.advanced_case_search.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/search, respond with HTTP 404

`api.cases.v2.test_helpers.case.advanced_case_search.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/search, respond with HTTP 200

`api.cases.v2.test_helpers.case.advanced_case_search.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/search, respond with HTTP 401

## api.cases.v2.test_helpers.case.change_access_settings module

`api.cases.v2.test_helpers.case.change_access_settings.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 403

`api.cases.v2.test_helpers.case.change_access_settings.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 404

`api.cases.v2.test_helpers.case.change_access_settings.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 200

`api.cases.v2.test_helpers.case.change_access_settings.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 401

## api.cases.v2.test_helpers.case.close_case module

`api.cases.v2.test_helpers.case.close_case.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/close, respond with HTTP 403

`api.cases.v2.test_helpers.case.close_case.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/close, respond with HTTP 404

`api.cases.v2.test_helpers.case.close_case.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/close, respond with HTTP 200

`api.cases.v2.test_helpers.case.close_case.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/close, respond with HTTP 401

## api.cases.v2.test_helpers.case.create_case module

`api.cases.v2.test_helpers.case.create_case.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 403

`api.cases.v2.test_helpers.case.create_case.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 404

`api.cases.v2.test_helpers.case.create_case.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 200

`api.cases.v2.test_helpers.case.create_case.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 401

## api.cases.v2.test_helpers.case.current_user_watcher_status module

`api.cases.v2.test_helpers.case.current_user_watcher_status.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 403

`api.cases.v2.test_helpers.case.current_user_watcher_status.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 404

`api.cases.v2.test_helpers.case.current_user_watcher_status.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 200

`api.cases.v2.test_helpers.case.current_user_watcher_status.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 401

## api.cases.v2.test_helpers.case.delete_attachment module

`api.cases.v2.test_helpers.case.delete_attachment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.delete_attachment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.delete_attachment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.delete_attachment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.delete_case module

`api.cases.v2.test_helpers.case.delete_case.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.delete_case.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.delete_case.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.delete_case.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.delete_case_link module

`api.cases.v2.test_helpers.case.delete_case_link.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.delete_case_link.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.delete_case_link.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.delete_case_link.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.delete_comment module

`api.cases.v2.test_helpers.case.delete_comment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.delete_comment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.delete_comment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.delete_comment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.download_attachment module

`api.cases.v2.test_helpers.case.download_attachment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+/download, respond with HTTP 403

`api.cases.v2.test_helpers.case.download_attachment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+/download, respond with HTTP 404

`api.cases.v2.test_helpers.case.download_attachment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+/download, respond with HTTP 200

`api.cases.v2.test_helpers.case.download_attachment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+/download, respond with HTTP 401

## api.cases.v2.test_helpers.case.edit_comment module

`api.cases.v2.test_helpers.case.edit_comment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.edit_comment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.edit_comment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.edit_comment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.get_attachment module

`api.cases.v2.test_helpers.case.get_attachment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.get_attachment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.get_attachment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.get_attachment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.get_case_comment module

`api.cases.v2.test_helpers.case.get_case_comment.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.get_case_comment.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.get_case_comment.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.get_case_comment.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.get_case_metadata_by_id module

`api.cases.v2.test_helpers.case.get_case_metadata_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.get_case_metadata_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.get_case_metadata_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.get_case_metadata_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.grant_access module

`api.cases.v2.test_helpers.case.grant_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 403

`api.cases.v2.test_helpers.case.grant_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 404

`api.cases.v2.test_helpers.case.grant_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 200

`api.cases.v2.test_helpers.case.grant_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_case_a_c_l module

`api.cases.v2.test_helpers.case.list_case_a_c_l.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_case_a_c_l.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_case_a_c_l.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_case_a_c_l.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_case_attachments module

`api.cases.v2.test_helpers.case.list_case_attachments.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_case_attachments.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_case_attachments.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_case_attachments.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/attachments, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_case_comments module

`api.cases.v2.test_helpers.case.list_case_comments.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_case_comments.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_case_comments.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_case_comments.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/comments, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_case_links module

`api.cases.v2.test_helpers.case.list_case_links.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_case_links.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_case_links.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_case_links.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/links, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_case_tags module

`api.cases.v2.test_helpers.case.list_case_tags.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_case_tags.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_case_tags.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_case_tags.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_case_watchers module

`api.cases.v2.test_helpers.case.list_case_watchers.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_case_watchers.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_case_watchers.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_case_watchers.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 401

## api.cases.v2.test_helpers.case.list_workflows module

`api.cases.v2.test_helpers.case.list_workflows.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows, respond with HTTP 403

`api.cases.v2.test_helpers.case.list_workflows.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows, respond with HTTP 404

`api.cases.v2.test_helpers.case.list_workflows.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows, respond with HTTP 200

`api.cases.v2.test_helpers.case.list_workflows.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows, respond with HTTP 401

## api.cases.v2.test_helpers.case.merge_cases module

`api.cases.v2.test_helpers.case.merge_cases.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/merge/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.merge_cases.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/merge/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.merge_cases.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/merge/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.merge_cases.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/merge/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.move_case module

`api.cases.v2.test_helpers.case.move_case.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/move, respond with HTTP 403

`api.cases.v2.test_helpers.case.move_case.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/move, respond with HTTP 404

`api.cases.v2.test_helpers.case.move_case.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/move, respond with HTTP 200

`api.cases.v2.test_helpers.case.move_case.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/move, respond with HTTP 401

## api.cases.v2.test_helpers.case.publish_case module

`api.cases.v2.test_helpers.case.publish_case.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/publish, respond with HTTP 403

`api.cases.v2.test_helpers.case.publish_case.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/publish, respond with HTTP 404

`api.cases.v2.test_helpers.case.publish_case.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/publish, respond with HTTP 200

`api.cases.v2.test_helpers.case.publish_case.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/publish, respond with HTTP 401

## api.cases.v2.test_helpers.case.remove_access module

`api.cases.v2.test_helpers.case.remove_access.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.remove_access.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.remove_access.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.remove_access.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/access/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.remove_case_contact_watcher module

`api.cases.v2.test_helpers.case.remove_case_contact_watcher.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/contact/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.remove_case_contact_watcher.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/contact/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.remove_case_contact_watcher.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/contact/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.remove_case_contact_watcher.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/contact/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.remove_case_tag_by_id module

`api.cases.v2.test_helpers.case.remove_case_tag_by_id.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.remove_case_tag_by_id.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.remove_case_tag_by_id.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.remove_case_tag_by_id.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.remove_case_tag_by_key_value module

`api.cases.v2.test_helpers.case.remove_case_tag_by_key_value.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.remove_case_tag_by_key_value.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.remove_case_tag_by_key_value.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.remove_case_tag_by_key_value.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/tags/w+/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.remove_case_watcher module

`api.cases.v2.test_helpers.case.remove_case_watcher.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.remove_case_watcher.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.remove_case_watcher.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.remove_case_watcher.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.remove_current_user_watcher module

`api.cases.v2.test_helpers.case.remove_current_user_watcher.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 403

`api.cases.v2.test_helpers.case.remove_current_user_watcher.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 404

`api.cases.v2.test_helpers.case.remove_current_user_watcher.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 200

`api.cases.v2.test_helpers.case.remove_current_user_watcher.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watch, respond with HTTP 401

## api.cases.v2.test_helpers.case.request_workflow module

`api.cases.v2.test_helpers.case.request_workflow.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/request, respond with HTTP 403

`api.cases.v2.test_helpers.case.request_workflow.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/request, respond with HTTP 404

`api.cases.v2.test_helpers.case.request_workflow.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/request, respond with HTTP 200

`api.cases.v2.test_helpers.case.request_workflow.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/workflows/w+/request, respond with HTTP 401

## api.cases.v2.test_helpers.case.search_case_statistics module

`api.cases.v2.test_helpers.case.search_case_statistics.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/stats, respond with HTTP 403

`api.cases.v2.test_helpers.case.search_case_statistics.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/stats, respond with HTTP 404

`api.cases.v2.test_helpers.case.search_case_statistics.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/stats, respond with HTTP 200

`api.cases.v2.test_helpers.case.search_case_statistics.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/stats, respond with HTTP 401

## api.cases.v2.test_helpers.case.simple_case_search module

`api.cases.v2.test_helpers.case.simple_case_search.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 403

`api.cases.v2.test_helpers.case.simple_case_search.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 404

`api.cases.v2.test_helpers.case.simple_case_search.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 200

`api.cases.v2.test_helpers.case.simple_case_search.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case, respond with HTTP 401

## api.cases.v2.test_helpers.case.update_case module

`api.cases.v2.test_helpers.case.update_case.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.update_case.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.update_case.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.update_case.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.update_case_watcher module

`api.cases.v2.test_helpers.case.update_case_watcher.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 403

`api.cases.v2.test_helpers.case.update_case_watcher.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 404

`api.cases.v2.test_helpers.case.update_case_watcher.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 200

`api.cases.v2.test_helpers.case.update_case_watcher.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers/w+, respond with HTTP 401

## api.cases.v2.test_helpers.case.update_watcher_settings module

`api.cases.v2.test_helpers.case.update_watcher_settings.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 403

`api.cases.v2.test_helpers.case.update_watcher_settings.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 404

`api.cases.v2.test_helpers.case.update_watcher_settings.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 200

`api.cases.v2.test_helpers.case.update_watcher_settings.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/cases/v2/case/w+/watchers, respond with HTTP 401

## Module contents